//  Copyright © 2012 Stephen Smally
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 2 of the License, or
//      (at your option) any later version.
//      
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//      
//      You should have received a copy of the GNU General Public License
//      along with this program; if not, write to the Free Software
//      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
//      MA 02110-1301, USA.
//      

using Gtk;
using PackageKit;
using Lsc.Backend;

namespace Lsc.Widgets {
    public class AppsTree : TreeView {
        // Signals
        public signal void selected_row (string pkg);
        
        // Vars
        private ListStore model;
        private TreeIter iter;
        private TreePath path;
        private Value value;
        private string stock_image;
        
        public void append_app (LscApp app) {
            /*if (app.get_info() == Info.INSTALLED) {
                stock_image = Stock.YES;
            } else {
                stock_image = null;
            }*/
            model.append(out iter);
            model.set(iter, 0, app.icon, 1, app.name+"\n"+app.summary, 2, stock_image, 3, app.id);
        }
        
        public void clear () {
            model.clear();
        }
        
        public void on_cursor_changed (TreeView widget) {
            get_cursor(out path, null);
            if (path != null) {
                model.get_iter(out iter, path);
                model.get_value(iter, 4, out value);
                selected_row(value.get_string());
            }
        }
        
        public AppsTree () {
            model = new ListStore(4,
                typeof(string), // Icon name
                typeof(string), // Name and description
                typeof(string), // Installed (Gtk.Stock)
                typeof(string)  // Package ID
            );
            
            set_model(model);
            
            CellRendererPixbuf icon_cell = new CellRendererPixbuf();
            icon_cell.stock_size = IconSize.DND;
            
            insert_column_with_attributes(-1, "Icon", icon_cell, "icon-name", 0);
            insert_column_with_attributes(-1, "Inst", new CellRendererPixbuf(), "stock-id", 2);
            insert_column_with_attributes(-1, "Name", new CellRendererText(), "text", 1);
            
            get_column(2).set_sort_column_id(1);
            get_column(2).set_expand(true);
            get_column(2).clicked();
            
            get_column(1).set_sort_column_id(2);
            
            cursor_changed.connect(on_cursor_changed);
            
            headers_visible = false;
        }
    }
    
    public class AppsView : Box {
        // Widgets
        public AppsTree apps_tree;
        public InfoMessage info_message;
        
        public AppsView () {
            orientation = Orientation.VERTICAL;
            
            apps_tree = new AppsTree();
            info_message = new InfoMessage();
            
            ScrolledWindow apps_tree_scroll = new ScrolledWindow(null, null);
            apps_tree_scroll.set_policy(PolicyType.NEVER, PolicyType.AUTOMATIC);
            apps_tree_scroll.add(apps_tree);
            
            apps_tree.selected_row.connect(info_message.update);
            
            pack_start(apps_tree_scroll, true, true, 0);
            pack_start(info_message, false, false, 0);
        }
    }
}
